==> data_from_mongo-1.6.tar.gz: data_from_mongo-1.6/data_from_mongo/setup.py <==
from distutils.core import setup
setup(
  name = 'data_from_mongo',         # How you named your package folder (MyLib)
  packages = ['data_from_mongo'],   # Chose the same as "name"
  version = '1.6',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'TYPE YOUR DESCRIPTION HERE',   # Give a short description about your library
  author = 'Tzviya',                   # Type in your name
  author_email = 'tzviya@vizible.zone',      # Type in your E-Mail
  url = 'https://github.com/user/reponame',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/tlangent2/data_from_mongo/archive/1.6.tar.gz',    # I explain this later on
  keywords = ['SOME', 'MEANINGFULL', 'KEYWORDS'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'sshtunnel',
          'pymongo',
          'osmnx',
          'matplotlib',
          'numpy',
          'geopy',
          'imageio',
          'pandas',
          'seaborn',
          'scipy',
          'requests',
          'pathlib',
          'datetime',
          'bson',
          'pyqtree', 
          'shapely',
          'networkx' 
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)

==> data_from_mongo-2.1.tar.gz: data_from_mongo-2.1/data_from_mongo/setup.py <==
from distutils.core import setup
setup(
  name = 'data_from_mongo',         # How you named your package folder (MyLib)
  packages = ['data_from_mongo'],   # Chose the same as "name"
  version = '2.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'TYPE YOUR DESCRIPTION HERE',   # Give a short description about your library
  author = 'Tzviya',                   # Type in your name
  author_email = 'tzviya@vizible.zone',      # Type in your E-Mail
  url = 'https://github.com/user/reponame',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/Viziblezone/data_from_mongo/archive/2.1.tar.gz',    # I explain this later on
  keywords = ['SOME', 'MEANINGFULL', 'KEYWORDS'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'sshtunnel',
          'pymongo',
          'osmnx',
          'matplotlib',
          'numpy',
          'geopy',
          'imageio',
          'pandas',
          'seaborn',
          'scipy',
          'requests',
          'pathlib',
          'datetime',
          'bson',
          'pyqtree', 
          'shapely',
          'networkx' 
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
